@@ -11,6 +11,7 @@ import io
 from typing import Dict, Callable, Type, TypeVar
 import importlib
 import warnings
+from .exceptions import ParseError
 
 
 T = TypeVar("T")
@@ -32,10 +33,6 @@ _parser_roots = {
 xml_ctx = XmlContext()
 
 
-class ParseError(XSDataParserError):
-    pass
-
-
 def get_version(sdf: str) -> str:
     """Returns the version of a SDF string.
 
@@ -137,9 +134,10 @@ def loads(
 
     if handler in ["XmlSaxHandler", "LxmlSaxHandler"]:
         warnings.warn(
-            "SAX handlers have been depreciated in xsData >= 21.9;"
+            "SAX handlers have been deprecated in xsData >= 21.9;"
             " falling back to EventHandler. If you need the SAX handler, please open an issue."
-            " To make this warning dissapear change `handler` to the corresponding EventHandler."
+            " To make this warning dissapear change `handler` to the corresponding EventHandler.",
+            DeprecationWarning,
         )
 
     if handler == "XmlSaxHandler":
